<?php

/**
 * Plugin Name: Geo EXIF Image Tagger
 * Description: Store and edit GPS metadata (longitude, latitude) in media images (JPEG, TIFF, PNG, WebP).
 * Version: 1.2.3
 * Author: Sebastian Weiß, Jakob Berger
 * Text Domain: geo-exif-image-tagger
 * Languages: /languages
 *
 * @package geit
 **/

/**
 * GEIT_BASE_URL.
 *
 * @since 1.1.0
 * @var type $var returns Plugin Base Url.
 */
define('GEIT_BASE_URL', plugin_dir_url(__FILE__));

/**
 * GEIT_BASE_DIR.
 *
 * @since 1.1.0
 * @var type $var Plugin Base Dir Path.
 */
define('GEIT_BASE_DIR', plugin_dir_path(__FILE__));

/**
 *
 * includes Autoload and GPS Wrapper.
 *
 * @since 1.1.0
 */
require_once GEIT_BASE_DIR . '/vendor/autoload.php';
require_once GEIT_BASE_DIR . '/include/gps.php';

/**
 *
 * include Plugin Update Checker.
 *
 * @since 1.1.1
 * @package geit
 * @subpackage GeoExifData
 */

use Lightweb_Media\Lightweb_Media_Plugin_Sidebar\LWM_Plugin_Sidebar;
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;

PucFactory::buildUpdateChecker(
	'http://plugins.lightweb-media.de/api?action=get_metadata&slug=geo-exif-image-tagger', //Metadata URL.
	__FILE__, //Full path to the main plugin file.
	'geo-exif-image-tagger' //Plugin slug. Usually it's the same as the name of the directory.
);

/**
 * Represents the GeoExifData class.
 *  @since 1.1.0
 * @package geit
 * @subpackage GeoExifData
 * @category Class
 */

class GeoExifData
{

	/**
	 * Initializes the class and registers the geit_exif_data function to the 'init' action hook.
	 *
	 * @since 1.1.0
	 */
	function __construct()
	{
		LWM_Plugin_Sidebar::get_instance(); // Root call to register translation files

		add_action('init', array($this, 'geit_exif_data'));
	}

	/**
	 * Loads the geit-exif-data-function.php file.
	 *
	 * @since 1.1.0
	 */
	public function geit_exif_data()
	{
		include GEIT_BASE_DIR . 'include/geit-exif-data-function.php';
	}
}

// Instantiate the GeoExifData class.
new GeoExifData();