<?php
/**
 * GEIT ExifFunctions includes Admin Pages.
 *
 * @since 1.0.1
 * @package geit
 **/
// Exit if accessed directly.
if (!defined('ABSPATH')) {
	exit;
}
/**
 * GEITExifFunctions class.
 */
if (!class_exists('GEITExifFunctions')) {
	class GEITExifFunctions
	{

		/**
		 * Add a sub-menu to the Media menu.
		 */


		/**
		 * Register the media sub menu
		 */

		function __construct()
		{
			$this->geit_exif_lib();
			add_action('admin_menu', array($this, 'geit_register_media_sub_menu'));
			add_action('wp_ajax_geit_image_search', array($this, 'geit_image_search'));
			add_action('wp_ajax_nopriv_geit_image_search', array($this, 'geit_image_search'));
			add_action('admin_footer', array($this, 'geit_enqueue_files'), 99);
		}

		// Include the EXIF library.
		function geit_exif_lib()
		{
			include GEIT_BASE_DIR . 'include/geit-exif-lib.php';
		}

		// Enqueue the JS and CSS files.
		function geit_enqueue_files()
		{
			if (empty($_GET['page'])) {
				$lat = !empty(get_option('geit-geo-tagger-lat')) ? get_option('geit-geo-tagger-lat') : '';
				$lng = !empty(get_option('geit-geo-tagger-lng')) ? get_option('geit-geo-tagger-lng') : '';
				$author = !empty(get_option('geit-geo-tagger-author')) ? get_option('geit-geo-tagger-author') : '';
				$description = !empty(get_option('geit-geo-tagger-description')) ? get_option('geit-geo-tagger-description') : '';
				echo '
		    	<script>
				    var lat = "' . $lat . '";
				    var lng = "' . $lng . '";
					var author = "' . $author . '";
				    var description = "' . $description . '";
				</script>
		    	';
				wp_register_script('geit-map-js', GEIT_BASE_URL . 'assets/js/geit-map-js.js');
				wp_enqueue_script('geit-map-js');
			}
		}
		// Add a sub-menu to the Media menu.
		function geit_register_media_sub_menu()
		{
			add_submenu_page(
				'upload.php',
				'Geo EXIF Image Tagger',
				'Geo EXIF Image Tagger',
				'manage_options',
				'exif-geo-tagger-page',
				'geit_geo_tagger_page'
			);
			add_submenu_page(
				'upload.php',
				'Exif Settings',
				'Exif Settings',
				'manage_options',
				'geo-tagger-setting',
				array($this, 'geit_geo_tagger_setting')
			);
		}


		/**
		 * Register the media sub menu
		 *
		 * @since 1.0.1
		 */
		function geit_geo_tagger_setting()
		{
			// enqueue css and js
			if ($_GET['page'] == 'geo-tagger-setting') {
				wp_register_style('geit-setting', GEIT_BASE_URL . 'assets/css/geit-setting.css');
				wp_enqueue_style('geit-setting');
				wp_register_script('geit-setting', GEIT_BASE_URL . 'assets/js/geit-setting.js');
				wp_enqueue_script('geit-setting');
			}
			// update option
			if (!empty($_POST)) {
				if (!validateCoordinates($_POST['geit-geo-tagger-lat'], $_POST['geit-geo-tagger-lng'])) {
					$main_message = 'GPS Data are wrong';
				} else {
					$center_lat = sanitize_text_field($_POST['geit-geo-tagger-lat']);
					$center_lng = sanitize_text_field($_POST['geit-geo-tagger-lng']);
					$author = sanitize_text_field($_POST['geit-geo-tagger-author']);
					$description = sanitize_text_field($_POST['geit-geo-tagger-description']);
					update_option('geit-geo-tagger-lat', trim($center_lat), 'yes');
					update_option('geit-geo-tagger-lng', trim($center_lng), 'yes');
					update_option('geit-geo-tagger-author', trim($author), 'yes');
					update_option('geit-geo-tagger-description', trim($description), 'yes');
					$main_message = 'Data updated successfully';
				}
			}
			// render template
			include GEIT_BASE_DIR . 'include/template/geit-geo-tagger-setting.php';
		}




		/**
		 * sanitize the input before saving it
		 *
		 * @param [array] $input
		 * @return array
		 */
		function fs_sanatizer($input)
		{
			if (isset($input['geit-geo-tagger-lat'])) {
				$input['geit-geo-tagger-lat'] = sanitize_text_field($input['geit-geo-tagger-lat']);
			}
			if (isset($input['geit-geo-tagger-lng'])) {
				$input['geit-geo-tagger-lng'] = sanitize_text_field($input['geit-geo-tagger-lng']);
			}
			if (isset($input['geit-geo-tagger-author'])) {
				$input['geit-geo-tagger-author'] = sanitize_text_field($input['geit-geo-tagger-author']);
			}
			if (isset($input['geit-geo-tagger-description'])) {
				$input['geit-geo-tagger-description'] = sanitize_text_field($input['geit-geo-tagger-description']);
			}
			return $input;
		}

		/**
		 * geit_image_search
		 *
		 * @since 1.0.1
		 * @return void
		 */
		function geit_image_search()
		{
			if (is_admin()) {
				$title = !empty(sanitize_text_field($_POST['data']['search'])) ? sanitize_text_field($_POST['data']['search']) : '';
				$images = [];
				$args = array(
					'post_type' => 'attachment',
					's' => $title,
				);
				foreach (geit_get_supported_mime_types() as $mimetype) {
					$args['post_mime_type'] = $mimetype;
					$query = get_posts($args);
					foreach ($query as $key => $attachment) {
						$images[$attachment->ID] = wp_get_attachment_image($attachment->ID);
					}
				}
				if (!empty($images)) {
					$ret = array(
						'status' => 'Success',
						'message' => 'Data get successfully.',
						'data' => $images,
					);
				} else {
					$ret = array(
						'status' => 'Fail',
						'message' => 'Image not found.',
					);
				}
				echo wp_json_encode($ret);
				exit;
			}
		}

	}
	new GEITExifFunctions();
}
