<?php
/**
 * GEIT helper functions and action hooks
 * @since 1.1.0
 * @package geit
 */

/**
 * Filter to add the 'geit-image-latitude' and 'geit-image-longitude' fields to the attachment fields.
 */
add_filter('attachment_fields_to_edit', 'geit_attachment_field_credit', 10, 2);

/**
 * Adds Actions to the 'wp_ajax_geit_store_exif_data' and 'wp_ajax_nopriv_geit_store_exif_data' hooks.
 */
add_action('wp_ajax_geit_store_exif_data', 'geit_store_exif_data');
add_action('wp_ajax_nopriv_geit_store_exif_data', 'geit_store_exif_data');

add_filter('attachment_fields_to_save', 'geit_attachment_field_credit_save', 10, 2);
add_action('http_api_curl', 'geit_custom_curl_timeout', 99, 1);

if (!function_exists('geit_custom_curl_timeout')) {
	function geit_custom_curl_timeout($handle)
	{
		curl_setopt($handle, CURLOPT_CONNECTTIMEOUT, 30);
		curl_setopt($handle, CURLOPT_TIMEOUT, 30);
	}
}

if (!function_exists('geit_attachment_field_credit')) {
	function geit_attachment_field_credit($form_fields, $post)
	{
		$file_url = wp_get_attachment_url($post->ID);
		$filetype = wp_check_filetype($file_url);

		if (in_array($filetype['type'], geit_get_supported_mime_types())) {
			$data_val = get_post_meta($post->ID, 'geit_image_latitude', true);
			$form_fields['custom8']['tr'] = "<tr align='center'>
				    <th colspan='2' style='text-align:center'>
				        <b style='font-size: 16px;'>" . __('Image EXIF Data', 'geo-exif-image-tagger') . "</b>
				    </th>
				</tr>
				<tr align='center' class='errMessageParent' style='display:none'>
				    <td colspan='2' style='text-align:center'>
				        <span class='errMessage'></span>
				    </td>
				</tr>
				";
			$form_fields['geit-image-latitude'] = array(
				'label' => 'Latitude',
				'input' => 'html',
				'html' => '<input type="text" class="text geit-image-input" id="geit-latitude" name="attachments[' . $post->ID . '][geit-image-latitude]"  value="' . get_post_meta($post->ID, 'geit_image_latitude', true) . '">',
			);

			$form_fields['geit-image-longitude'] = array(
				'label' => 'Longitude',
				'input' => 'html',
				'html' => '<input type="text" class="text geit-image-input" id="geit-longitude" name="attachments[' . $post->ID . '][geit-image-longitude]" value="' . get_post_meta($post->ID, 'geit_image_longitude', true) . '">',
			);

			$form_fields['geit-image-author'] = array(
				'label' => 'EXIF Author/Copyright',
				'input' => 'html',
				'html' => '<input type="text" class="text geit-image-input" id="geit-author" name="attachments[' . $post->ID . '][geit-image-author]" value="' . get_post_meta($post->ID, 'geit_image_author', true) . '">',
			);

			$form_fields['geit-image-description'] = array(
				'label' => 'EXIF Description',
				'input' => 'html',
				'html' => '
			            <input type="text" class="text geit-image-input" id="attachments-' . $post->ID . '-geit-image-description" name="attachments[' . $post->ID . '][geit-image-description]" value="' . get_post_meta($post->ID, 'geit_image_description', true) . '">',
			);
			return $form_fields;
		} else {
			$url = get_option('_geit_server_url');
			$form_fields['custom8']['tr'] = "
				<tr align='center'>
				    <th colspan='2' style='text-align:center'></th>
				</tr>";
			return $form_fields;
		}
	}
}

if (!function_exists('geit_geo_tagger_page')) {
	function geit_geo_tagger_page()
	{
		wp_localize_script(
			'ajax-script',
			'ajax_obj',
			array(
				'ajaxurl' => admin_url('admin-ajax.php'),
				'ajax_nonce' => wp_create_nonce('any_value_here'),
			)
		);
		if (!empty($_GET['page'])) {
			if ($_GET['page'] == 'exif-geo-tagger-page') {
				wp_register_style('geit-gallery-css', GEIT_BASE_URL . 'assets/css/geit-gallery-css.css');
				wp_enqueue_style('geit-gallery-css');

				wp_register_script('geit-gallery-js', GEIT_BASE_URL . 'assets/js/geit-gallery-js.js');
				wp_enqueue_script('geit-gallery-js');
			}
		}
		$attachments = get_children(
			array(
				'post_parent' => get_the_ID(),
				'post_type' => 'attachment',
				'post_mime_type' => 'image',
			)
		);

		include GEIT_BASE_DIR . 'include/template/geit-media-temp.php';
	}
}

if (!function_exists('geit_attachment_field_credit_save')) {
	function geit_attachment_field_credit_save($post, $attachment)
	{
		$lat = preg_match('/^(\+|-)?(?:90(?:(?:\.0{1,20})?)|(?:[0-9]|[1-8][0-9])(?:(?:\.[0-9]{1,20})?))$/', $attachment['geit-image-latitude']);

		$lon = preg_match('/^(\+|-)?(?:180(?:(?:\.0{1,20})?)|(?:[0-9]|[1-9][0-9]|1[0-7][0-9])(?:(?:\.[0-9]{1,20})?))$/', $attachment['geit-image-longitude']);

		if (isset($attachment['geit-image-latitude']) && isset($attachment['geit-image-longitude']) && ($lat == 1) && ($lon == 1)) {

			$path = get_attached_file($post['ID']);
			$latitude = sanitize_text_field($attachment['geit-image-latitude']);
			$longitude = sanitize_text_field($attachment['geit-image-longitude']);
			$author = sanitize_text_field($attachment['geit-image-author']);
			$description = sanitize_text_field($attachment['geit-image-description']);
			$r = null;
			$err = null;

			try {
				$r = addGpsInfo($path, $path, trim($longitude), trim($latitude), trim($author), trim($description), true);
			} catch (\Exception $ex) {
				$err = $ex;
			}
			if (!empty($r)) {
				update_post_meta($post['ID'], 'geit_image_description', trim($description));
				update_post_meta($post['ID'], 'geit_image_author', trim($author));
				update_post_meta($post['ID'], 'geit_image_latitude', trim($latitude));
				update_post_meta($post['ID'], 'geit_image_longitude', trim($longitude));
				$result = array(
					'success' => true,
					'data' => 'Data updated successfully.',
				);
			} else {
				$result = array(
					'success' => false,
					'data' => "Something went wrong: $err",
				);
			}
		}
		return $post;
	}
}

if (!function_exists('geit_store_exif_data')) {
	function geit_store_exif_data()
	{
		$lat = preg_match('/^(\+|-)?(?:90(?:(?:\.0{1,20})?)|(?:[0-9]|[1-8][0-9])(?:(?:\.[0-9]{1,20})?))$/', $_POST['data']['lat']);
		$lon = preg_match('/^(\+|-)?(?:180(?:(?:\.0{1,20})?)|(?:[0-9]|[1-9][0-9]|1[0-7][0-9])(?:(?:\.[0-9]{1,20})?))$/', $_POST['data']['long']);

		if (isset($_POST['data']['lat']) && isset($_POST['data']['long']) && ($lat == 1) && ($lon == 1)) {
			foreach ($_POST['data']['images'] as $img_id) {
				$path = get_attached_file($img_id);
				$latitude = sanitize_text_field($_POST['data']['lat']);
				$longitude = sanitize_text_field($_POST['data']['long']);
				$author = sanitize_text_field($_POST['data']['aut']);
				$description = sanitize_text_field($_POST['data']['des']);

				$r = addGpsInfo($path, $path, trim($longitude), trim($latitude), trim($author), trim($description), true);
				if (!empty($r)) {
					update_post_meta($img_id, 'geit_image_latitude', trim($latitude));
					update_post_meta($img_id, 'geit_image_longitude', trim($longitude));
					update_post_meta($img_id, 'geit_image_author', trim($author));
					update_post_meta($img_id, 'geit_image_description', trim($description));
					$response = json_encode(
						array(
							'result' => true,
							'code' => 200,
							'message' => 'Data update successfully.',
						)
					);
				} else {
					$response = json_encode(
						array(
							'result' => false,
							'code' => 406,
							'message' => 'Something went wrong, Please try again.',
						)
					);
				}
			}
		} else {
			$response = json_encode(
				array(
					'result' => false,
					'code' => 406,
					'message' => 'Latitude and Longitude are required.',
				)
			);
		}
		echo $response;
		exit;
	}
}

add_action('wp_ajax_geit_save_media_exif_data', 'geit_save_media_exif_data_callback');
add_action('wp_ajax_nopriv_geit_save_media_exif_data', 'geit_save_media_exif_data_callback');


function geit_save_media_exif_data_callback()
{
	$id = $_POST['id'];

	$key = 'attachments[' . $id;
	$latitude = $_POST['data'][$key]['geit-image-latitude'];
	$longitude = $_POST['data'][$key]['geit-image-longitude'];
	$author = $_POST['data'][$key]['geit-image-author'];
	$description = $_POST['data'][$key]['geit-image-description'];

	$file_url = wp_get_original_image_path($id);

	update_post_meta($id, 'geit_image_author', trim($author));
	update_post_meta($id, 'geit_image_latitude', trim($latitude));
	update_post_meta($id, 'geit_image_longitude', trim($longitude));
	update_post_meta($id, 'geit_image_description', trim($description));
	$message = 'Data updated successfully.';
	$response = 1;
	try {
		addGpsInfo(
			$file_url,
			$file_url,
			$longitude,
			$latitude,
			$author,
			$description,
			true
		);
	} catch (Exception $e) {
		$message = $e;
	}

	$return = array(
		'success' => true,
		'message' => $message,
		'response' => $response,
	);
	wp_send_json($return);
	die();

}




/**
 * Retrieves the array of supported mime types for Geo Exif Data.
 *
 * @return array The array of the supported mime types 'image/jpeg', 'image/jpg', 'image/webp', 'image/png'.
 *
 * @since 1.1.0
 */
if (!function_exists('geit_get_supported_mime_types')) {
	function geit_get_supported_mime_types()
	{
		return ['image/jpeg', 'image/jpg', 'image/webp', 'image/png'];
	}
}

/**
 * Applies the 'change_attachment_metadata' filter to modify attachment metadata when it is updated.
 *
 * @param array $data          The attachment metadata.
 * @param int   $attachment_id The ID of the attachment.
 *
 * @return array The modified attachment metadata.
 *
 * @since 1.1.0
 */
add_filter('wp_update_attachment_metadata', 'change_attachment_metadata', 10, 2);

/**
 * Modifies the attachment metadata by adding geit_image_latitude, geit_image_longitude, geit_image_author, and geit_image_description post meta.
 *
 * @param array $data          The attachment metadata.
 * @param int   $attachment_id The ID of the attachment.
 *
 * @return array The modified attachment metadata.
 *
 * @since 1.1.0
 */
function change_attachment_metadata($data, $attachment_id)
{
	$image = read_exif_data(wp_upload_dir()['basedir'] . '/' . $data['file']);
	if (!isset($image)) {
		return $data;
	}
	add_post_meta($attachment_id, 'geit_image_latitude', trim($image['gps_coordinates_simple']['latitude']));
	add_post_meta($attachment_id, 'geit_image_longitude', trim($image['gps_coordinates_simple']['longitude']));
	add_post_meta($attachment_id, 'geit_image_author', trim($image['ARTIST']));
	add_post_meta($attachment_id, 'geit_image_description', trim($image['IMAGE_DESCRIPTION']));
	return $data;

}

/**
 * Hooks into the 'attachment_updated' action and executes the custom_media_update function.
 *
 * @param int $attachment_id The ID of the updated attachment.
 *
 * @since 1.1.0
 */
function custom_media_update($attachment_id)
{
	$file_url = wp_get_attachment_url($attachment_id);

	$fields = [
		'geit-image-longitude',
		'geit-image-latitude',
		'geit-image-author',
		'geit-image-description',
	];
	$data = [];
	if (isset($_POST['attachments'])) {
		foreach ($fields as $field) {
			if (isset($_POST['attachments'][$attachment_id][$field])) {
				$data[$field] = sanitize_text_field($_POST['attachments'][$attachment_id][$field]);
			}
		}
		if (count($data) === 4) {
			addGpsInfo(
				$file_url,
				$file_url,
				$data['geit-image-longitude'],
				$data['geit-image-latitude'],
				$data['geit-image-author'],
				$data['geit-image-description'],
				true
			);
		}
	}
}

// Register the custom_media_update function to the 'attachment_updated' action hook.
add_action('attachment_updated', 'custom_media_update');