<?php

namespace Lightweb_Media\Lightweb_Media_Plugin_Sidebar;

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Lightweb_Media\Lightweb_Media_Plugin_Sidebar\Abstracts\LWM_Plugin_Sidebar_Singleton_Abstract;
use Lightweb_Media\Lightweb_Media_Plugin_Sidebar\Interfaces\LWM_Plugin_Sidebar_Interface;

/**
 * Class LWM_Plugin_Sidebar
 *
 * @package Lightweb_Media\Lightweb_Media_Plugin_Sidebar
 */
class LWM_Plugin_Sidebar extends LWM_Plugin_Sidebar_Singleton_Abstract implements LWM_Plugin_Sidebar_Interface {

	/**
	 * The package base bath
	 *
	 * @var string
	 */
	private string $abspath;

	/**
	 * Lightweb Media Plugin Sidebar version
	 *
	 * @var string
	 */
	public string $version = '1.0.0';

	/**
	 * LWM_Plugin_Sidebar constructor
	 */
	public function __construct() {
		$this->abspath = dirname( __DIR__ ) . DIRECTORY_SEPARATOR;

		$this->define_constants();
		$this->init_hooks();
	}

	/**
	 * Init / set up hooks
	 */
	private function init_hooks(): void {
		add_action( 'init', array( $this, 'init_action' ) );
	}

	/**
	 * Define Lightweb Media Plugin Sidebar constants
	 */
	private function define_constants(): void {
		$this->define_constant( 'LWM_PLUGIN_SIDEBAR_LANG_DIR', $this->abspath . 'i18n' . DIRECTORY_SEPARATOR . 'languages' . DIRECTORY_SEPARATOR );
		$this->define_constant( 'LWM_PLUGIN_SIDEBAR_TEMPLATES_DIR', $this->abspath . 'templates' . DIRECTORY_SEPARATOR );
		$this->define_constant( 'LWM_PLUGIN_SIDEBAR_ASSETS_URL', $this->abspath . 'assets' . DIRECTORY_SEPARATOR );
	}

	/**
	 * Define constant if not already set
	 *
	 * @param string $name
	 * @param string|bool $value
	 */
	private function define_constant( string $name, $value ): void {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * Handles the the output of the plugin sidebar
	 *
	 * @return void
	 */
	public function output(): void {
		$sidebar = Constants::get_constant( 'LWM_PLUGIN_SIDEBAR_TEMPLATES_DIR' ) . DIRECTORY_SEPARATOR . 'sidebar.php';

		if ( ! file_exists( $sidebar ) ) {
			_doing_it_wrong( __FUNCTION__, wp_kses_post( sprintf( __( '%s does not exist.', 'lightweb-media-plugin-sidebar' ), '<code>' . $sidebar . '</code>' ) ), '1.0.0' );

			return;
		}

		require $sidebar;
	}

	/**
	 * Handle init
	 */
	public function init_action(): void {
		$this->load_plugin_textdomain();
	}

	/**
	 * Load Lightweb Media Plugin Sidebar translation files
	 */
	private function load_plugin_textdomain(): void {
		$locale = determine_locale();
		$locale = apply_filters( 'plugin_locale', $locale, 'lightweb-media-plugin-sidebar' );

		unload_textdomain( 'lightweb-media-plugin-sidebar' );
		load_textdomain( 'lightweb-media-plugin-sidebar', Constants::get_constant( 'LWM_PLUGIN_SIDEBAR_LANG_DIR' ) . 'lightweb-media-plugin-sidebar-' . $locale . '.mo' );
		load_plugin_textdomain( 'lightweb-media-plugin-sidebar', false, Constants::get_constant( 'LWM_PLUGIN_SIDEBAR_LANG_DIR' ) );
	}
}
